Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/airball/__init__.py | 7 | 0 | 0 | 100%
src/airball/analytic.py | 154 | 139 | 0 | 10%
src/airball/core.py | 304 | 257 | 0 | 15%
src/airball/environments.py | 179 | 54 | 0 | 70%
src/airball/imf.py | 88 | 17 | 0 | 81%
src/airball/stars.py | 419 | 121 | 0 | 71%
src/airball/tools.py | 328 | 166 | 0 | 49%
src/airball/units.py | 7 | 0 | 0 | 100%
tests/core.py | 26 | 0 | 0 | 100%
tests/environments.py | 8 | 0 | 0 | 100%
tests/stars.py | 166 | 8 | 0 | 95%
Total | 1686 | 762 | 0 | 55%

No items found using the specified filter.